==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ColorScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescriptionMetadata } from "./PropertyUpdatedEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var ColorScaleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColorScaleDescriptionMetadata, _super);
    function ColorScaleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorScaleDescriptionMetadata.b = function (a) {
        if (ColorScaleDescriptionMetadata.a == null) {
            ColorScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColorScaleDescriptionMetadata.c(ColorScaleDescriptionMetadata.a);
        }
        if (a.k(ColorScaleDescriptionMetadata.a)) {
            return;
        }
        a.ab(ColorScaleDescriptionMetadata.a);
        PropertyUpdatedEventArgsDescriptionMetadata.d(a);
    };
    ColorScaleDescriptionMetadata.c = function (a) {
        a.item("PropertyUpdatedRef", "EventRef::propertyUpdated");
    };
    ColorScaleDescriptionMetadata.d = function (a) {
        ColorScaleDescriptionMetadata.b(a);
        a.ac("ColorScale", ColorScaleDescriptionMetadata.a);
    };
    ColorScaleDescriptionMetadata.$t = markType(ColorScaleDescriptionMetadata, 'ColorScaleDescriptionMetadata');
    ColorScaleDescriptionMetadata.a = null;
    return ColorScaleDescriptionMetadata;
}(Base));
export { ColorScaleDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ColorScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescriptionMetadata } from "./PropertyUpdatedEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var ColorScaleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColorScaleDescriptionMetadata, _super);
    function ColorScaleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorScaleDescriptionMetadata.b = function (a) {
        if (ColorScaleDescriptionMetadata.a == null) {
            ColorScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColorScaleDescriptionMetadata.c(ColorScaleDescriptionMetadata.a);
        }
        if (a.k(ColorScaleDescriptionMetadata.a)) {
            return;
        }
        a.ac(ColorScaleDescriptionMetadata.a);
        PropertyUpdatedEventArgsDescriptionMetadata.d(a);
    };
    ColorScaleDescriptionMetadata.c = function (a) {
        a.item("PropertyUpdatedRef", "EventRef::propertyUpdated");
    };
    ColorScaleDescriptionMetadata.d = function (a) {
        ColorScaleDescriptionMetadata.b(a);
        a.ad("ColorScale", ColorScaleDescriptionMetadata.a);
    };
    ColorScaleDescriptionMetadata.$t = markType(ColorScaleDescriptionMetadata, 'ColorScaleDescriptionMetadata');
    ColorScaleDescriptionMetadata.a = null;
    return ColorScaleDescriptionMetadata;
}(Base));
export { ColorScaleDescriptionMetadata };
